==> hal-console-3.0.21.Final-redhat-00001-sources.jar: org/jboss/hal/ballroom/Clipboard.java <==
/*
 * Copyright 2015-2016 Red Hat, Inc, and individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.hal.ballroom;

import elemental2.dom.HTMLElement;
import jsinterop.annotations.JsConstructor;
import jsinterop.annotations.JsFunction;
import jsinterop.annotations.JsOverlay;
import jsinterop.annotations.JsType;

import static jsinterop.annotations.JsPackage.GLOBAL;
import static org.jboss.hal.resources.UIConstants.OBJECT;

/**
 * Clipboard implementation based on <a href="http://zeroclipboard.org/">ZeroClipboard</a>.
 *
 * @see <a href="http://zeroclipboard.org/">http://zeroclipboard.org/</a>
 */
@JsType(name = "ZeroClipboard", namespace = GLOBAL, isNative = true)
public class Clipboard {

    @JsConstructor
    @SuppressWarnings("UnusedParameters")
    public Clipboard(HTMLElement element) {
    }

    native void on(String event, ClipboardHandler handler);

    @JsOverlay
    public final void onCopy(ClipboardHandler handler) {
        on("copy", handler);
    }

    public native void setText(String text);


    @JsFunction
    @FunctionalInterface
    public interface ClipboardHandler {

        void handleEvent(ClipboardEvent event);
    }


    @JsType(isNative = true, namespace = GLOBAL, name = OBJECT)
    public static class ClipboardEvent {

        public Clipboard client;
    }
}

==> hal-console-3.2.4.Final-redhat-00001-sources.jar: org/jboss/hal/ballroom/Clipboard.java <==
/*
 * Copyright 2015-2016 Red Hat, Inc, and individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.hal.ballroom;

import elemental2.dom.HTMLElement;
import jsinterop.annotations.JsConstructor;
import jsinterop.annotations.JsFunction;
import jsinterop.annotations.JsOverlay;
import jsinterop.annotations.JsType;

import static jsinterop.annotations.JsPackage.GLOBAL;
import static org.jboss.hal.resources.UIConstants.OBJECT;

/**
 * Clipboard implementation based on <a href="https://zeroclipboard.github.io/">ZeroClipboard</a>.
 *
 * @see <a href="https://zeroclipboard.github.io/">https://zeroclipboard.github.io/</a>
 */
@JsType(name = "ZeroClipboard", namespace = GLOBAL, isNative = true)
public class Clipboard {

    @JsConstructor
    @SuppressWarnings("UnusedParameters")
    public Clipboard(HTMLElement element) {
    }

    native void on(String event, ClipboardHandler handler);

    @JsOverlay
    public final void onCopy(ClipboardHandler handler) {
        on("copy", handler);
    }

    public native void setText(String text);


    @JsFunction
    @FunctionalInterface
    public interface ClipboardHandler {

        void handleEvent(ClipboardEvent event);
    }


    @JsType(isNative = true, namespace = GLOBAL, name = OBJECT)
    public static class ClipboardEvent {

        public Clipboard client;
    }
}
